@@ -2,8 +2,8 @@ import numpy as np
 import pandas as pd
 from sklearn.base import BaseEstimator, TransformerMixin
 
-from rexify.dataclasses import Schema
 from rexify.features.base import HasSchemaMixin
+from rexify.schema import Schema
 from rexify.utils import get_target_id
 
 
@@ -30,7 +30,6 @@ class Sequencer(BaseEstimator, TransformerMixin, HasSchemaMixin):
                       'user': {'age': 'numerical', 'gender': 'categorical',
                                'user_id': 'id'}},
               timestamp_feature='timestamp', window_size=4)
-
         >>> transformed = sequencer.transform(events)
 
     """
